@@ -12,7 +12,7 @@ class BondFuture(Future):
                  settlement_type, contract_size, point_value, tick_size, quote_unit=None, cheapest_to_deliver_id=None,
                  currency=None, asset_issuer_id=None, asset_status='Active', issue_date=date.min, expiry_date=date.max,
                  display_name='', description='', country_id=None, venue_id=None,
-                 links=None, references=None, *args, **kwargs):
+                 comments=None, links=None, references=None, *args, **kwargs):
         """
 
         :param asset_manager_id: The asset manager who owns the data for this BondFuture
@@ -39,8 +39,8 @@ class BondFuture(Future):
                                          asset_issuer_id=asset_issuer_id, asset_status=asset_status,
                                          display_name=display_name, currency=currency,
                                          description=description, country_id=country_id, venue_id=venue_id,
-                                         links=links, references=references, issue_date=issue_date,
-                                         expiry_date=expiry_date,
+                                         comments=comments, links=links, references=references,
+                                         issue_date=issue_date, expiry_date=expiry_date,
                                          *args, **kwargs)
 
     @property
