@@ -1,7 +1,7 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 from amaascore.assets.asset import Asset
-
+from datetime import date
 
 class Equity(Asset):
 
@@ -10,9 +10,10 @@ class Equity(Asset):
     def pricing_method():
         return 'Market'
 
+
     def __init__(self, asset_manager_id, asset_id, share_class='Common', asset_issuer_id=None, asset_status='Active',
-                 issue_date=None, display_name='', description='', country_id=None, venue_id=None, roll_price=False,
-                 currency=None, links=None, references=None, *args, **kwargs):
+                 issue_date=date.min, display_name='', description='', country_id=None, venue_id=None, roll_price=False,
+                 currency=None, comments=None, links=None, references=None, *args, **kwargs):
         if not hasattr(self, 'asset_class'):  # A more specific child class may have already set this
             self.asset_class = 'Equity'
         self.share_class = share_class
@@ -20,5 +21,5 @@ class Equity(Asset):
                                      asset_issuer_id=asset_issuer_id, asset_status=asset_status,
                                      display_name=display_name, roll_price=roll_price, currency=currency,
                                      description=description, country_id=country_id, venue_id=venue_id,
-                                     links=links, references=references, issue_date=issue_date,
+                                     comments=comments, links=links, references=references, issue_date=issue_date,
                                      *args, **kwargs)
